summaryrefslogtreecommitdiffstats
path: root/include/linux/regulator
diff options
context:
space:
mode:
authorJames Ban2014-08-08 07:27:04 +0200
committerMark Brown2014-08-16 23:46:22 +0200
commit005547e0828ce9064afebb1e6d56a18efd80e7a3 (patch)
treee862fd217711306c4dcaa260dda9fbca9a7685ff /include/linux/regulator
parentLinux 3.17-rc1 (diff)
downloadkernel-qcow2-linux-005547e0828ce9064afebb1e6d56a18efd80e7a3.tar.gz
kernel-qcow2-linux-005547e0828ce9064afebb1e6d56a18efd80e7a3.tar.xz
kernel-qcow2-linux-005547e0828ce9064afebb1e6d56a18efd80e7a3.zip
regulator: da9211: support DA9213
This is a patch for supporting DA9213. Signed-off-by: James Ban <james.ban.opensource@diasemi.com> Signed-off-by: Mark Brown <broonie@linaro.org>
Diffstat (limited to 'include/linux/regulator')
-rw-r--r--include/linux/regulator/da9211.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/include/linux/regulator/da9211.h b/include/linux/regulator/da9211.h
index 0981ce0e72cc..658c3c33f4c0 100644
--- a/include/linux/regulator/da9211.h
+++ b/include/linux/regulator/da9211.h
@@ -1,5 +1,5 @@
/*
* da9211.h - Regulator device driver for DA9211
* Copyright (C) 2014 Dialog Semiconductor Ltd.
*
* This library is free software; you can redistribute it and/or
@@ -20,6 +20,11 @@
#define DA9211_MAX_REGULATORS 2
+enum da9211_chip_id {
+ DA9211,
+ DA9213,
+};
+
struct da9211_pdata {
/*
* Number of buck
@@ -1,5 +1,5 @@
/*
- * da9211.h - Regulator device driver for DA9211
+ * da9211.h - Regulator device driver for DA9211/DA9213
* Copyright (C) 2014 Dialog Semiconductor Ltd.
*